
## CATO-CLI - mutation.accountManagement.removeAccount:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeAccount) for documentation on this operation.

### Usage for mutation.accountManagement.removeAccount:

`catocli mutation accountManagement removeAccount -h`

`catocli mutation accountManagement removeAccount <json>`

`catocli mutation accountManagement removeAccount "$(cat < removeAccount.json)"`

`catocli mutation accountManagement removeAccount '{}'`

#### Operation Arguments for mutation.accountManagement.removeAccount ####
`accountId` [ID] - (required) N/A 
